@@ -17,19 +17,15 @@ use Bugzilla::WebService::Component;
 use Bugzilla::Error;
 
 BEGIN {
-    *Bugzilla::WebService::Component::rest_resources = \&_rest_resources;
-};
+  *Bugzilla::WebService::Component::rest_resources = \&_rest_resources;
+}
 
 sub _rest_resources {
-    my $rest_resources = [
-        qr{^/component$}, {
-            POST => {
-                method => 'create',
-                success_code => STATUS_CREATED
-            }
-        },
-    ];
-    return $rest_resources;
+  my $rest_resources = [
+    qr{^/component$},
+    {POST => {method => 'create', success_code => STATUS_CREATED}},
+  ];
+  return $rest_resources;
 }
 
 1;
